@@ -1,10 +1,7 @@
 /**
  * @file Vector.h
  * @date 17.02.2014
- *
- * @brief classes simple linear algebra
- *
- * @author: M. Baaske
+ * @author: franke
  */
 
 #ifndef VECTOR_H_
@@ -32,8 +29,6 @@ template<class T>
 inline const T &MIN(const T &a, const T &b)
 {return b < a ? (b) : (a);}
 
-using namespace std;
-
 namespace STGM {
 
 
@@ -48,6 +43,7 @@ struct CPoint {
   CPoint(const CPoint &x);
   CPoint(value_t x0 = 0.0, value_t x1 = 0.0, value_t x2 = 0.0);
   CPoint(const std::vector<value_t> &x);
+  CPoint(value_t * v);
 
   CPoint& operator= (const CPoint &p_);
   value_t &operator[](size_t i) { return p[i]; }
@@ -64,7 +60,6 @@ struct CPoint {
 
 };
 
-
 template <size_t N>
 CPoint<N>::CPoint(const value_t a) : n_(N) {
   for (size_t i=0; i<n_; i++) p[i]=a;
@@ -94,6 +89,12 @@ CPoint<N>::CPoint(const std::vector<value_t> &x) : n_(N) {
   Memcpy(p,x.data(),n_);
 }
 
+template <size_t N>
+CPoint<N>::CPoint(value_t * v) : n_(N) {
+  for (size_t i=0; i<n_; i++)
+    p[i] = v[i];
+}
+
 
 template <size_t N>
 CPoint<N>& CPoint<N>::operator=(const CPoint<N>& x) {
@@ -119,7 +120,7 @@ inline typename CPoint<N>::value_t CPoint<N>::Length() const {
   value_t tmp=0;
   for (size_t i=0; i<n_; i++)
     tmp += SQR(p[i]);
-   return sqrt(tmp);
+   return std::sqrt(tmp);
 }
 
 template <size_t N>
@@ -137,6 +138,7 @@ bool CPoint<N>::operator <(const CPoint &q) const {
 typedef CPoint<2> CPoint2d;
 typedef CPoint<3> CPoint3d;
 
+
 /** Simple vector class */
 template<class T, size_t N>
 class CVector {
@@ -183,6 +185,7 @@ inline const T & CVector<T,N>::operator[](const int i) const { return data[i]; }
 typedef CVector<double,2> CVector2d;
 typedef CVector<double,3> CVector3d;
 
+
 template <class T,size_t N>
 CVector<T,N>::CVector(const value_t a) : n_(N) {
   for (size_t i=0; i<n_; i++) data[i]=a;
@@ -191,17 +194,11 @@ CVector<T,N>::CVector(const value_t a) : n_(N) {
 template <class T,size_t N>
 CVector<T,N>::CVector(const CVector &v) : n_(N) {
   if(v.size()!=n_)
-    error("Vector Length error in copy construct 1.");
+    error("Vector Length error in copy construct");
   for (size_t i=0; i<n_; i++)
     data[i] = v.data[i];
 }
 
-template <class T,size_t N>
-CVector<T,N>::CVector(T * v) : n_(N) {
-  for (size_t i=0; i<n_; i++)
-    data[i] = v[i];
-}
-
 
 template <class T,size_t N>
 CVector<T,N>::CVector(value_t x0, value_t x1, value_t x2) : n_(N) {
@@ -215,10 +212,16 @@ CVector<T,N>::CVector(value_t x0, value_t x1, value_t x2) : n_(N) {
 template <class T,size_t N>
 CVector<T,N>::CVector(const std::vector<value_t> &v) : n_(N) {
   if(v.size() != n_)
-    error("Vector Length error in vector copy 2.");
+    error("Vector Length error in vector copy");
   Memcpy(data,v.data(),n_);
 }
 
+template <class T,size_t N>
+CVector<T,N>::CVector(T * v) : n_(N) {
+  for (size_t i=0; i<n_; i++)
+    data[i] = v[i];
+}
+
 
 ///unary vector class operators
 template <class T,size_t N>
@@ -299,7 +302,7 @@ inline typename CVector<T,N>::value_t CVector<T,N>::Length() const {
   value_t tmp=0;
   for (size_t i=0; i<n_; i++)
     tmp += SQR(data[i]);
-   return sqrt(tmp);
+   return std::sqrt(tmp);
 }
 
 template <class T,size_t N>
@@ -324,14 +327,18 @@ class CMatrix2d {
   double data[2][2];
 
   public:
-  CMatrix2d() {  std::memset(data, 0, sizeof(data)); }
-   ~CMatrix2d() {}
+  CMatrix2d() {
+    std::memset(data, 0, sizeof(data));
+  }
+
+  ~CMatrix2d() {}
 
   CMatrix2d(const double *a) {
-    data[0][0] = a[0];
-    data[1][0] = a[1];
-    data[0][1] = a[2];
-    data[1][1] = a[3];
+    /**  from R column-major to C row-major */
+	data[0][0] = a[0];
+	data[0][1] = a[1];
+	data[1][0] = a[2];
+	data[1][1] = a[3];
   }
 
   double *operator[](int i) { return data[i]; }
@@ -345,19 +352,21 @@ class CMatrix2d {
       }
   }
 
+  void nullify() { std::memset(data, 0, sizeof(data)); }
+
 };
 
 inline const CMatrix2d operator*(const CMatrix2d &a, const CMatrix2d &b) {
-    CMatrix2d c;
+    CMatrix2d m;
     for (int i = 0; i < 2; ++i) {
       for (int j = 0; j < 2; ++j) {
-        c[i][j] = 0.0;
+        m[i][j] = 0.0;
         for (int k = 0; k < 2; ++k) {
-          c[i][j] += a[i][k] * b[k][j];
+          m[i][j] += a[i][k] * b[k][j];
         }
       }
     }
-    return c;
+    return m;
 }
 
 
@@ -366,20 +375,11 @@ class CMatrix3d {
 
   public:
 
-   CMatrix3d() {  std::memset(data, 0, sizeof(data)); }
-  ~CMatrix3d() {}
+   CMatrix3d() {
+     std::memset(data, 0, sizeof(data));
+   }
 
-  CMatrix3d(const double *a) {
-      data[0][0] = a[0];
-      data[1][0] = a[1];
-      data[2][0] = a[2];
-      data[0][1] = a[3];
-      data[1][1] = a[4];
-      data[2][1] = a[5];
-      data[0][2] = a[6];
-      data[1][2] = a[7];
-      data[2][2] = a[8];
-  }
+  ~CMatrix3d() {}
 
   double *operator[](int i) { return data[i]; }
   const double *operator[](int i) const { return data[i]; }
@@ -392,6 +392,8 @@ class CMatrix3d {
     }
   }
 
+  void nullify() { std::memset(data, 0, sizeof(data));  }
+
 };
 
 /**
