@@ -2,8 +2,9 @@
 
 library(simLife)
 library(unfoldr)
+
 library(parallel)
-options(mc.cores=2L)
+options(simLife.mc=2L)
 
 theta <- list("size"=list(0.1))
 box <- list("xrange"=c(0,3),"yrange"=c(0,3),"zrange"=c(0,9))
